# Holds common settings for *all* systems, including both servers and
# clients.

{ pkgs, oxalica, agenix, ... }: {

	imports = [ agenix.nixosModule ];

    nix = {
        optimise.automatic = true;
        extraOptions = ''
            experimental-features = nix-command flakes
        '';
    };

    nixpkgs = {
        config = { allowUnfree = true; };
        overlays = [

            # Import overlays defined under the `overlays/` directory.
            (import ./overlays)

            # Clients need Rust for development, servers need Rust for
            # deployment.
            oxalica.overlay
            
        ];
    };

    age.secrets."website-secret".file = ./secrets/website-secret.age;

    boot.cleanTmpDir = true;

    environment.systemPackages = [

        # Include common packages I use everywhere, like `rg`
        # and `exa`
        (import ./env.nix { inherit pkgs; })

    ];

}
